# encoding: UTF-8

module TZInfo
  module Indexes
    module Timezones
      include TimezoneIndexDefinition

      timezone 'Africa/Abidjan'
      timezone 'Africa/Accra'
      linked_timezone 'Africa/Addis_Ababa'
      timezone 'Africa/Algiers'
      linked_timezone 'Africa/Asmara'
      linked_timezone 'Africa/Asmera'
      linked_timezone 'Africa/Bamako'
      linked_timezone 'Africa/Bangui'
      linked_timezone 'Africa/Banjul'
      timezone 'Africa/Bissau'
      linked_timezone 'Africa/Blantyre'
      linked_timezone 'Africa/Brazzaville'
      linked_timezone 'Africa/Bujumbura'
      timezone 'Africa/Cairo'
      timezone 'Africa/Casablanca'
      timezone 'Africa/Ceuta'
      linked_timezone 'Africa/Conakry'
      linked_timezone 'Africa/Dakar'
      linked_timezone 'Africa/Dar_es_Salaam'
      linked_timezone 'Africa/Djibouti'
      linked_timezone 'Africa/Douala'
      timezone 'Africa/El_Aaiun'
      linked_timezone 'Africa/Freetown'
      linked_timezone 'Africa/Gaborone'
      linked_timezone 'Africa/Harare'
      timezone 'Africa/Johannesburg'
      linked_timezone 'Africa/Juba'
      linked_timezone 'Africa/Kampala'
      timezone 'Africa/Khartoum'
      linked_timezone 'Africa/Kigali'
      linked_timezone 'Africa/Kinshasa'
      timezone 'Africa/Lagos'
      linked_timezone 'Africa/Libreville'
      linked_timezone 'Africa/Lome'
      linked_timezone 'Africa/Luanda'
      linked_timezone 'Africa/Lubumbashi'
      linked_timezone 'Africa/Lusaka'
      linked_timezone 'Africa/Malabo'
      timezone 'Africa/Maputo'
      linked_timezone 'Africa/Maseru'
      linked_timezone 'Africa/Mbabane'
      linked_timezone 'Africa/Mogadishu'
      timezone 'Africa/Monrovia'
      timezone 'Africa/Nairobi'
      timezone 'Africa/Ndjamena'
      linked_timezone 'Africa/Niamey'
      linked_timezone 'Africa/Nouakchott'
      linked_timezone 'Africa/Ouagadougou'
      linked_timezone 'Africa/Porto-Novo'
      linked_timezone 'Africa/Sao_Tome'
      linked_timezone 'Africa/Timbuktu'
      timezone 'Africa/Tripoli'
      timezone 'Africa/Tunis'
      timezone 'Africa/Windhoek'
      timezone 'America/Adak'
      timezone 'America/Anchorage'
      linked_timezone 'America/Anguilla'
      linked_timezone 'America/Antigua'
      timezone 'America/Araguaina'
      timezone 'America/Argentina/Buenos_Aires'
      timezone 'America/Argentina/Catamarca'
      linked_timezone 'America/Argentina/ComodRivadavia'
      timezone 'America/Argentina/Cordoba'
      timezone 'America/Argentina/Jujuy'
      timezone 'America/Argentina/La_Rioja'
      timezone 'America/Argentina/Mendoza'
      timezone 'America/Argentina/Rio_Gallegos'
      timezone 'America/Argentina/Salta'
      timezone 'America/Argentina/San_Juan'
      timezone 'America/Argentina/San_Luis'
      timezone 'America/Argentina/Tucuman'
      timezone 'America/Argentina/Ushuaia'
      linked_timezone 'America/Aruba'
      timezone 'America/Asuncion'
      timezone 'America/Atikokan'
      linked_timezone 'America/Atka'
      timezone 'America/Bahia'
      timezone 'America/Bahia_Banderas'
      timezone 'America/Barbados'
      timezone 'America/Belem'
      timezone 'America/Belize'
      timezone 'America/Blanc-Sablon'
      timezone 'America/Boa_Vista'
      timezone 'America/Bogota'
      timezone 'America/Boise'
      linked_timezone 'America/Buenos_Aires'
      timezone 'America/Cambridge_Bay'
      timezone 'America/Campo_Grande'
      timezone 'America/Cancun'
      timezone 'America/Caracas'
      linked_timezone 'America/Catamarca'
      timezone 'America/Cayenne'
      linked_timezone 'America/Cayman'
      timezone 'America/Chicago'
      timezone 'America/Chihuahua'
      linked_timezone 'America/Coral_Harbour'
      linked_timezone 'America/Cordoba'
      timezone 'America/Costa_Rica'
      timezone 'America/Creston'
      timezone 'America/Cuiaba'
      timezone 'America/Curacao'
      timezone 'America/Danmarkshavn'
      timezone 'America/Dawson'
      timezone 'America/Dawson_Creek'
      timezone 'America/Denver'
      timezone 'America/Detroit'
      linked_timezone 'America/Dominica'
      timezone 'America/Edmonton'
      timezone 'America/Eirunepe'
      timezone 'America/El_Salvador'
      linked_timezone 'America/Ensenada'
      timezone 'America/Fort_Nelson'
      linked_timezone 'America/Fort_Wayne'
      timezone 'America/Fortaleza'
      timezone 'America/Glace_Bay'
      timezone 'America/Godthab'
      timezone 'America/Goose_Bay'
      timezone 'America/Grand_Turk'
      linked_timezone 'America/Grenada'
      linked_timezone 'America/Guadeloupe'
      timezone 'America/Guatemala'
      timezone 'America/Guayaquil'
      timezone 'America/Guyana'
      timezone 'America/Halifax'
      timezone 'America/Havana'
      timezone 'America/Hermosillo'
      timezone 'America/Indiana/Indianapolis'
      timezone 'America/Indiana/Knox'
      timezone 'America/Indiana/Marengo'
      timezone 'America/Indiana/Petersburg'
      timezone 'America/Indiana/Tell_City'
      timezone 'America/Indiana/Vevay'
      timezone 'America/Indiana/Vincennes'
      timezone 'America/Indiana/Winamac'
      linked_timezone 'America/Indianapolis'
      timezone 'America/Inuvik'
      timezone 'America/Iqaluit'
      timezone 'America/Jamaica'
      linked_timezone 'America/Jujuy'
      timezone 'America/Juneau'
      timezone 'America/Kentucky/Louisville'
      timezone 'America/Kentucky/Monticello'
      linked_timezone 'America/Knox_IN'
      linked_timezone 'America/Kralendijk'
      timezone 'America/La_Paz'
      timezone 'America/Lima'
      timezone 'America/Los_Angeles'
      linked_timezone 'America/Louisville'
      linked_timezone 'America/Lower_Princes'
      timezone 'America/Maceio'
      timezone 'America/Managua'
      timezone 'America/Manaus'
      linked_timezone 'America/Marigot'
      timezone 'America/Martinique'
      timezone 'America/Matamoros'
      timezone 'America/Mazatlan'
      linked_timezone 'America/Mendoza'
      timezone 'America/Menominee'
      timezone 'America/Merida'
      timezone 'America/Metlakatla'
      timezone 'America/Mexico_City'
      timezone 'America/Miquelon'
      timezone 'America/Moncton'
      timezone 'America/Monterrey'
      timezone 'America/Montevideo'
      linked_timezone 'America/Montreal'
      linked_timezone 'America/Montserrat'
      timezone 'America/Nassau'
      timezone 'America/New_York'
      timezone 'America/Nipigon'
      timezone 'America/Nome'
      timezone 'America/Noronha'
      timezone 'America/North_Dakota/Beulah'
      timezone 'America/North_Dakota/Center'
      timezone 'America/North_Dakota/New_Salem'
      timezone 'America/Ojinaga'
      timezone 'America/Panama'
      timezone 'America/Pangnirtung'
      timezone 'America/Paramaribo'
      timezone 'America/Phoenix'
      timezone 'America/Port-au-Prince'
      timezone 'America/Port_of_Spain'
      linked_timezone 'America/Porto_Acre'
      timezone 'America/Porto_Velho'
      timezone 'America/Puerto_Rico'
      timezone 'America/Rainy_River'
      timezone 'America/Rankin_Inlet'
      timezone 'America/Recife'
      timezone 'America/Regina'
      timezone 'America/Resolute'
      timezone 'America/Rio_Branco'
      linked_timezone 'America/Rosario'
      linked_timezone 'America/Santa_Isabel'
      timezone 'America/Santarem'
      timezone 'America/Santiago'
      timezone 'America/Santo_Domingo'
      timezone 'America/Sao_Paulo'
      timezone 'America/Scoresbysund'
      linked_timezone 'America/Shiprock'
      timezone 'America/Sitka'
      linked_timezone 'America/St_Barthelemy'
      timezone 'America/St_Johns'
      linked_timezone 'America/St_Kitts'
      linked_timezone 'America/St_Lucia'
      linked_timezone 'America/St_Thomas'
      linked_timezone 'America/St_Vincent'
      timezone 'America/Swift_Current'
      timezone 'America/Tegucigalpa'
      timezone 'America/Thule'
      timezone 'America/Thunder_Bay'
      timezone 'America/Tijuana'
      timezone 'America/Toronto'
      linked_timezone 'America/Tortola'
      timezone 'America/Vancouver'
      linked_timezone 'America/Virgin'
      timezone 'America/Whitehorse'
      timezone 'America/Winnipeg'
      timezone 'America/Yakutat'
      timezone 'America/Yellowknife'
      timezone 'Antarctica/Casey'
      timezone 'Antarctica/Davis'
      timezone 'Antarctica/DumontDUrville'
      timezone 'Antarctica/Macquarie'
      timezone 'Antarctica/Mawson'
      linked_timezone 'Antarctica/McMurdo'
      timezone 'Antarctica/Palmer'
      timezone 'Antarctica/Rothera'
      linked_timezone 'Antarctica/South_Pole'
      timezone 'Antarctica/Syowa'
      timezone 'Antarctica/Troll'
      timezone 'Antarctica/Vostok'
      linked_timezone 'Arctic/Longyearbyen'
      linked_timezone 'Asia/Aden'
      timezone 'Asia/Almaty'
      timezone 'Asia/Amman'
      timezone 'Asia/Anadyr'
      timezone 'Asia/Aqtau'
      timezone 'Asia/Aqtobe'
      timezone 'Asia/Ashgabat'
      linked_timezone 'Asia/Ashkhabad'
      timezone 'Asia/Baghdad'
      linked_timezone 'Asia/Bahrain'
      timezone 'Asia/Baku'
      timezone 'Asia/Bangkok'
      timezone 'Asia/Barnaul'
      timezone 'Asia/Beirut'
      timezone 'Asia/Bishkek'
      timezone 'Asia/Brunei'
      linked_timezone 'Asia/Calcutta'
      timezone 'Asia/Chita'
      timezone 'Asia/Choibalsan'
      linked_timezone 'Asia/Chongqing'
      linked_timezone 'Asia/Chungking'
      timezone 'Asia/Colombo'
      linked_timezone 'Asia/Dacca'
      timezone 'Asia/Damascus'
      timezone 'Asia/Dhaka'
      timezone 'Asia/Dili'
      timezone 'Asia/Dubai'
      timezone 'Asia/Dushanbe'
      timezone 'Asia/Gaza'
      linked_timezone 'Asia/Harbin'
      timezone 'Asia/Hebron'
      timezone 'Asia/Ho_Chi_Minh'
      timezone 'Asia/Hong_Kong'
      timezone 'Asia/Hovd'
      timezone 'Asia/Irkutsk'
      linked_timezone 'Asia/Istanbul'
      timezone 'Asia/Jakarta'
      timezone 'Asia/Jayapura'
      timezone 'Asia/Jerusalem'
      timezone 'Asia/Kabul'
      timezone 'Asia/Kamchatka'
      timezone 'Asia/Karachi'
      linked_timezone 'Asia/Kashgar'
      timezone 'Asia/Kathmandu'
      linked_timezone 'Asia/Katmandu'
      timezone 'Asia/Khandyga'
      timezone 'Asia/Kolkata'
      timezone 'Asia/Krasnoyarsk'
      timezone 'Asia/Kuala_Lumpur'
      timezone 'Asia/Kuching'
      linked_timezone 'Asia/Kuwait'
      linked_timezone 'Asia/Macao'
      timezone 'Asia/Macau'
      timezone 'Asia/Magadan'
      timezone 'Asia/Makassar'
      timezone 'Asia/Manila'
      linked_timezone 'Asia/Muscat'
      timezone 'Asia/Nicosia'
      timezone 'Asia/Novokuznetsk'
      timezone 'Asia/Novosibirsk'
      timezone 'Asia/Omsk'
      timezone 'Asia/Oral'
      linked_timezone 'Asia/Phnom_Penh'
      timezone 'Asia/Pontianak'
      timezone 'Asia/Pyongyang'
      timezone 'Asia/Qatar'
      timezone 'Asia/Qyzylorda'
      timezone 'Asia/Rangoon'
      timezone 'Asia/Riyadh'
      linked_timezone 'Asia/Saigon'
      timezone 'Asia/Sakhalin'
      timezone 'Asia/Samarkand'
      timezone 'Asia/Seoul'
      timezone 'Asia/Shanghai'
      timezone 'Asia/Singapore'
      timezone 'Asia/Srednekolymsk'
      timezone 'Asia/Taipei'
      timezone 'Asia/Tashkent'
      timezone 'Asia/Tbilisi'
      timezone 'Asia/Tehran'
      linked_timezone 'Asia/Tel_Aviv'
      linked_timezone 'Asia/Thimbu'
      timezone 'Asia/Thimphu'
      timezone 'Asia/Tokyo'
      timezone 'Asia/Tomsk'
      linked_timezone 'Asia/Ujung_Pandang'
      timezone 'Asia/Ulaanbaatar'
      linked_timezone 'Asia/Ulan_Bator'
      timezone 'Asia/Urumqi'
      timezone 'Asia/Ust-Nera'
      linked_timezone 'Asia/Vientiane'
      timezone 'Asia/Vladivostok'
      timezone 'Asia/Yakutsk'
      timezone 'Asia/Yekaterinburg'
      timezone 'Asia/Yerevan'
      timezone 'Atlantic/Azores'
      timezone 'Atlantic/Bermuda'
      timezone 'Atlantic/Canary'
      timezone 'Atlantic/Cape_Verde'
      linked_timezone 'Atlantic/Faeroe'
      timezone 'Atlantic/Faroe'
      linked_timezone 'Atlantic/Jan_Mayen'
      timezone 'Atlantic/Madeira'
      timezone 'Atlantic/Reykjavik'
      timezone 'Atlantic/South_Georgia'
      linked_timezone 'Atlantic/St_Helena'
      timezone 'Atlantic/Stanley'
      linked_timezone 'Australia/ACT'
      timezone 'Australia/Adelaide'
      timezone 'Australia/Brisbane'
      timezone 'Australia/Broken_Hill'
      linked_timezone 'Australia/Canberra'
      timezone 'Australia/Currie'
      timezone 'Australia/Darwin'
      timezone 'Australia/Eucla'
      timezone 'Australia/Hobart'
      linked_timezone 'Australia/LHI'
      timezone 'Australia/Lindeman'
      timezone 'Australia/Lord_Howe'
      timezone 'Australia/Melbourne'
      linked_timezone 'Australia/NSW'
      linked_timezone 'Australia/North'
      timezone 'Australia/Perth'
      linked_timezone 'Australia/Queensland'
      linked_timezone 'Australia/South'
      timezone 'Australia/Sydney'
      linked_timezone 'Australia/Tasmania'
      linked_timezone 'Australia/Victoria'
      linked_timezone 'Australia/West'
      linked_timezone 'Australia/Yancowinna'
      linked_timezone 'Brazil/Acre'
      linked_timezone 'Brazil/DeNoronha'
      linked_timezone 'Brazil/East'
      linked_timezone 'Brazil/West'
      timezone 'CET'
      timezone 'CST6CDT'
      linked_timezone 'Canada/Atlantic'
      linked_timezone 'Canada/Central'
      linked_timezone 'Canada/East-Saskatchewan'
      linked_timezone 'Canada/Eastern'
      linked_timezone 'Canada/Mountain'
      linked_timezone 'Canada/Newfoundland'
      linked_timezone 'Canada/Pacific'
      linked_timezone 'Canada/Saskatchewan'
      linked_timezone 'Canada/Yukon'
      linked_timezone 'Chile/Continental'
      linked_timezone 'Chile/EasterIsland'
      linked_timezone 'Cuba'
      timezone 'EET'
      timezone 'EST'
      timezone 'EST5EDT'
      linked_timezone 'Egypt'
      linked_timezone 'Eire'
      timezone 'Etc/GMT'
      linked_timezone 'Etc/GMT+0'
      timezone 'Etc/GMT+1'
      timezone 'Etc/GMT+10'
      timezone 'Etc/GMT+11'
      timezone 'Etc/GMT+12'
      timezone 'Etc/GMT+2'
      timezone 'Etc/GMT+3'
      timezone 'Etc/GMT+4'
      timezone 'Etc/GMT+5'
      timezone 'Etc/GMT+6'
      timezone 'Etc/GMT+7'
      timezone 'Etc/GMT+8'
      timezone 'Etc/GMT+9'
      linked_timezone 'Etc/GMT-0'
      timezone 'Etc/GMT-1'
      timezone 'Etc/GMT-10'
      timezone 'Etc/GMT-11'
      timezone 'Etc/GMT-12'
      timezone 'Etc/GMT-13'
      timezone 'Etc/GMT-14'
      timezone 'Etc/GMT-2'
      timezone 'Etc/GMT-3'
      timezone 'Etc/GMT-4'
      timezone 'Etc/GMT-5'
      timezone 'Etc/GMT-6'
      timezone 'Etc/GMT-7'
      timezone 'Etc/GMT-8'
      timezone 'Etc/GMT-9'
      linked_timezone 'Etc/GMT0'
      linked_timezone 'Etc/Greenwich'
      timezone 'Etc/UCT'
      timezone 'Etc/UTC'
      linked_timezone 'Etc/Universal'
      linked_timezone 'Etc/Zulu'
      timezone 'Europe/Amsterdam'
      timezone 'Europe/Andorra'
      timezone 'Europe/Astrakhan'
      timezone 'Europe/Athens'
      linked_timezone 'Europe/Belfast'
      timezone 'Europe/Belgrade'
      timezone 'Europe/Berlin'
      linked_timezone 'Europe/Bratislava'
      timezone 'Europe/Brussels'
      timezone 'Europe/Bucharest'
      timezone 'Europe/Budapest'
      linked_timezone 'Europe/Busingen'
      timezone 'Europe/Chisinau'
      timezone 'Europe/Copenhagen'
      timezone 'Europe/Dublin'
      timezone 'Europe/Gibraltar'
      linked_timezone 'Europe/Guernsey'
      timezone 'Europe/Helsinki'
      linked_timezone 'Europe/Isle_of_Man'
      timezone 'Europe/Istanbul'
      linked_timezone 'Europe/Jersey'
      timezone 'Europe/Kaliningrad'
      timezone 'Europe/Kiev'
      timezone 'Europe/Kirov'
      timezone 'Europe/Lisbon'
      linked_timezone 'Europe/Ljubljana'
      timezone 'Europe/London'
      timezone 'Europe/Luxembourg'
      timezone 'Europe/Madrid'
      timezone 'Europe/Malta'
      linked_timezone 'Europe/Mariehamn'
      timezone 'Europe/Minsk'
      timezone 'Europe/Monaco'
      timezone 'Europe/Moscow'
      linked_timezone 'Europe/Nicosia'
      timezone 'Europe/Oslo'
      timezone 'Europe/Paris'
      linked_timezone 'Europe/Podgorica'
      timezone 'Europe/Prague'
      timezone 'Europe/Riga'
      timezone 'Europe/Rome'
      timezone 'Europe/Samara'
      linked_timezone 'Europe/San_Marino'
      linked_timezone 'Europe/Sarajevo'
      timezone 'Europe/Simferopol'
      linked_timezone 'Europe/Skopje'
      timezone 'Europe/Sofia'
      timezone 'Europe/Stockholm'
      timezone 'Europe/Tallinn'
      timezone 'Europe/Tirane'
      linked_timezone 'Europe/Tiraspol'
      timezone 'Europe/Ulyanovsk'
      timezone 'Europe/Uzhgorod'
      linked_timezone 'Europe/Vaduz'
      linked_timezone 'Europe/Vatican'
      timezone 'Europe/Vienna'
      timezone 'Europe/Vilnius'
      timezone 'Europe/Volgograd'
      timezone 'Europe/Warsaw'
      linked_timezone 'Europe/Zagreb'
      timezone 'Europe/Zaporozhye'
      timezone 'Europe/Zurich'
      linked_timezone 'GB'
      linked_timezone 'GB-Eire'
      linked_timezone 'GMT'
      linked_timezone 'GMT+0'
      linked_timezone 'GMT-0'
      linked_timezone 'GMT0'
      linked_timezone 'Greenwich'
      timezone 'HST'
      linked_timezone 'Hongkong'
      linked_timezone 'Iceland'
      linked_timezone 'Indian/Antananarivo'
      timezone 'Indian/Chagos'
      timezone 'Indian/Christmas'
      timezone 'Indian/Cocos'
      linked_timezone 'Indian/Comoro'
      timezone 'Indian/Kerguelen'
      timezone 'Indian/Mahe'
      timezone 'Indian/Maldives'
      timezone 'Indian/Mauritius'
      linked_timezone 'Indian/Mayotte'
      timezone 'Indian/Reunion'
      linked_timezone 'Iran'
      linked_timezone 'Israel'
      linked_timezone 'Jamaica'
      linked_timezone 'Japan'
      linked_timezone 'Kwajalein'
      linked_timezone 'Libya'
      timezone 'MET'
      timezone 'MST'
      timezone 'MST7MDT'
      linked_timezone 'Mexico/BajaNorte'
      linked_timezone 'Mexico/BajaSur'
      linked_timezone 'Mexico/General'
      linked_timezone 'NZ'
      linked_timezone 'NZ-CHAT'
      linked_timezone 'Navajo'
      linked_timezone 'PRC'
      timezone 'PST8PDT'
      timezone 'Pacific/Apia'
      timezone 'Pacific/Auckland'
      timezone 'Pacific/Bougainville'
      timezone 'Pacific/Chatham'
      timezone 'Pacific/Chuuk'
      timezone 'Pacific/Easter'
      timezone 'Pacific/Efate'
      timezone 'Pacific/Enderbury'
      timezone 'Pacific/Fakaofo'
      timezone 'Pacific/Fiji'
      timezone 'Pacific/Funafuti'
      timezone 'Pacific/Galapagos'
      timezone 'Pacific/Gambier'
      timezone 'Pacific/Guadalcanal'
      timezone 'Pacific/Guam'
      timezone 'Pacific/Honolulu'
      linked_timezone 'Pacific/Johnston'
      timezone 'Pacific/Kiritimati'
      timezone 'Pacific/Kosrae'
      timezone 'Pacific/Kwajalein'
      timezone 'Pacific/Majuro'
      timezone 'Pacific/Marquesas'
      linked_timezone 'Pacific/Midway'
      timezone 'Pacific/Nauru'
      timezone 'Pacific/Niue'
      timezone 'Pacific/Norfolk'
      timezone 'Pacific/Noumea'
      timezone 'Pacific/Pago_Pago'
      timezone 'Pacific/Palau'
      timezone 'Pacific/Pitcairn'
      timezone 'Pacific/Pohnpei'
      linked_timezone 'Pacific/Ponape'
      timezone 'Pacific/Port_Moresby'
      timezone 'Pacific/Rarotonga'
      linked_timezone 'Pacific/Saipan'
      linked_timezone 'Pacific/Samoa'
      timezone 'Pacific/Tahiti'
      timezone 'Pacific/Tarawa'
      timezone 'Pacific/Tongatapu'
      linked_timezone 'Pacific/Truk'
      timezone 'Pacific/Wake'
      timezone 'Pacific/Wallis'
      linked_timezone 'Pacific/Yap'
      linked_timezone 'Poland'
      linked_timezone 'Portugal'
      linked_timezone 'ROC'
      linked_timezone 'ROK'
      linked_timezone 'Singapore'
      linked_timezone 'Turkey'
      linked_timezone 'UCT'
      linked_timezone 'US/Alaska'
      linked_timezone 'US/Aleutian'
      linked_timezone 'US/Arizona'
      linked_timezone 'US/Central'
      linked_timezone 'US/East-Indiana'
      linked_timezone 'US/Eastern'
      linked_timezone 'US/Hawaii'
      linked_timezone 'US/Indiana-Starke'
      linked_timezone 'US/Michigan'
      linked_timezone 'US/Mountain'
      linked_timezone 'US/Pacific'
      linked_timezone 'US/Pacific-New'
      linked_timezone 'US/Samoa'
      linked_timezone 'UTC'
      linked_timezone 'Universal'
      linked_timezone 'W-SU'
      timezone 'WET'
      linked_timezone 'Zulu'
    end
  end
end
